package com.srs.comprehensive.service;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import com.baomidou.mybatisplus.extension.service.IService;
import com.srs.comprehensive.domain.SrsClass;
import com.srs.comprehensive.domain.Vo.SrsClassInfo;
import com.srs.comprehensive.domain.Vo.CphSearch;


/**
 * 班级信息
Service接口
 *
 * @author srs
 * @date 2023-06-27
 */
public interface ISrsClassService  extends IService<SrsClass>
{

    public List<SrsClass> listInSchoolClass(CphSearch param);

    public List<SrsClassInfo> listClassView(CphSearch param);

    /**
     * 查询班级信息

     *
     * @param classId 班级信息
主键
     * @return 班级信息

     */
    public SrsClass selectSrsClassByClassId(Long classId);

    /**
     * 查询班级信息
列表
     *
     * @param srsClass 班级信息

     * @return 班级信息
集合
     */
    public List<SrsClass> selectSrsClassList(SrsClass srsClass);

    /**
     * 通过班级代码查询班级信息
     * @param classCode
     * @return
     */
    public SrsClass selectSrsClassByClassCode(String classCode);

    /**
     * 查询班级id对应的和name
     * @param srsClass
     * @return
     */
    public ArrayList<Object> selectSrsClassName(SrsClass srsClass);

    /**
     * 新增班级信息

     *
     * @param srsClass 班级信息

     * @return 结果
     */
    public int insertSrsClass(SrsClass srsClass);

    /**
     * 修改班级信息

     *
     * @param srsClass 班级信息

     * @return 结果
     */
    public int updateSrsClass(SrsClass srsClass);

    /**
     * 批量删除班级信息

     *
     * @param classIds 需要删除的班级信息
主键集合
     * @return 结果
     */
    public int deleteSrsClassByClassIds(Long[] classIds);

    /**
     * 删除班级信息
信息
     *
     * @param classId 班级信息
主键
     * @return 结果
     */
    public int deleteSrsClassByClassId(Long classId);

    /**
     * 从中间表同步班级数据
     * @return 结果
     */
    public Map<String,Object> datasync();

    void sqlserverSynchronousMYSQL(List<Map> list);
    void synchronousMYSQL(List<Map> list);

}
